/*******************************************************************************
* File Name: IDAC8_OC_OV_PM.c  
* Version 1.60
*
*  Description:
*     This file provides the power management source code to API for the
*     IDAC8.  
*
*   Note:
*     None
*
*******************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/


#include "IDAC8_OC_OV.h"

static IDAC8_OC_OV_backupStruct IDAC8_OC_OV_backup;


/*******************************************************************************
* Function Name: IDAC8_OC_OV_SaveConfig
********************************************************************************
* Summary:
*  Save the current user configuration
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
*******************************************************************************/
void IDAC8_OC_OV_SaveConfig(void)
{
    IDAC8_OC_OV_backup.data_value = IDAC8_OC_OV_Data;
}


/*******************************************************************************
* Function Name: IDAC8_OC_OV_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
*******************************************************************************/
void IDAC8_OC_OV_RestoreConfig(void)
{
    IDAC8_OC_OV_Data = IDAC8_OC_OV_backup.data_value;
}


/*******************************************************************************
* Function Name: IDAC8_OC_OV_Sleep
********************************************************************************
* Summary:
*     Stop and Save the user configuration
*
* Parameters:  
*  void:  
*
* Return: 
*  void
*
* Global variables:
*  IDAC8_OC_OV_backup.enableState:  Is modified depending on the enable state
*  of the block before entering sleep mode.
*
*******************************************************************************/
void IDAC8_OC_OV_Sleep(void)
{
    if(IDAC8_OC_OV_ACT_PWR_EN == (IDAC8_OC_OV_PWRMGR & IDAC8_OC_OV_ACT_PWR_EN))
    {
        /* IDAC8 is enabled */
        IDAC8_OC_OV_backup.enableState = 1u;
    }
    else
    {
        /* IDAC8 is disabled */
        IDAC8_OC_OV_backup.enableState = 0u;
    }
    
    IDAC8_OC_OV_Stop();
    IDAC8_OC_OV_SaveConfig();
}


/*******************************************************************************
* Function Name: IDAC8_OC_OV_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  IDAC8_OC_OV_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void IDAC8_OC_OV_Wakeup(void)
{
    IDAC8_OC_OV_RestoreConfig();
    
    if(IDAC8_OC_OV_backup.enableState == 1u)
    {
        /* Enable IDAC8's operation */
        IDAC8_OC_OV_Enable();
       
        /* Set the data register */
        IDAC8_OC_OV_SetValue(IDAC8_OC_OV_Data);
    } /* Do nothing if IDAC8 was disabled before */    
}


/* [] END OF FILE */
