/*******************************************************************************
* File Name: OCComp_PM.c  
* Version 1.60
*
*  Description:
*     This file provides the power management source code to API for the
*     Comparator.  
*
*   Note:
*     None
*
*******************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/


#include "OCComp.h"

static OCComp_backupStruct OCComp_backup;


/*******************************************************************************
* Function Name: OCComp_SaveConfig
********************************************************************************
*
* Summary:
*     Save the current user configuration
*
* Parameters:  
*  void:  
*
* Return: 
*  void
*
* Reentrant:
*  No
*
*******************************************************************************/
void OCComp_SaveConfig(void)
{
    /* Empty since all are system reset for retention flops */
}


/*******************************************************************************
* Function Name: OCComp_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Reentrant:
*  No
*
*******************************************************************************/
void OCComp_RestoreConfig(void)
{
    /* Empty since all are system reset for retention flops */    
}


/*******************************************************************************
* Function Name: OCComp_Sleep
********************************************************************************
*
* Summary:
*     Stop and Save the user configuration
*
* Parameters:  
*  void:  
*
* Return: 
*  void
*
* Global variables:
*  OCComp_backup.enableState:  Is modified depending on the enable state
*  of the block before entering sleep mode.
*
* Reentrant:
*  No
*
*******************************************************************************/
void OCComp_Sleep(void)
{
    /* Save Comp's enable state */    
    if(OCComp_ACT_PWR_EN == (OCComp_PWRMGR & OCComp_ACT_PWR_EN))
    {
        /* Comp is enabled */
        OCComp_backup.enableState = 1u;
    }
    else
    {
        /* Comp is disabled */
        OCComp_backup.enableState = 0u;
    }    
    
    OCComp_Stop();
    OCComp_SaveConfig();
}


/*******************************************************************************
* Function Name: OCComp_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  OCComp_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void OCComp_Wakeup(void) 
{
    OCComp_RestoreConfig();
    
    if(OCComp_backup.enableState == 1u)
    {
        /* Enable Comp's operation */
        OCComp_Enable();

    } /* Do nothing if Comp was disabled before */    
    
}


/* [] END OF FILE */
