/*******************************************************************************
* File Name: OVComp.h  
* Version 1.60
*
*  Description:
*    This file contains the function prototypes and constants used in
*    the Analog Comparitor User Module.
*
*   Note:
*     
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_COMP_OVComp_H) 
#define CY_COMP_OVComp_H

#include "cytypes.h"
#include "cyfitter.h" 

#define OVComp_RECALMODE 0u


/***************************************
   Conditional Compilation Parameters
****************************************/

/* PSoC3 ES2 or early */
#define OVComp_PSOC3_ES2  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A)    && \
                                    (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2))                    
/* PSoC5 ES1 or early */
#define OVComp_PSOC5_ES1  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A)    && \
                                    (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_5A_ES1))
/* PSoC3 ES3 or later */
#define OVComp_PSOC3_ES3  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A)    && \
                                    (CYDEV_CHIP_REVISION_USED > CYDEV_CHIP_REVISION_3A_ES2))                    
/* PSoC5 ES2 or later */
#define OVComp_PSOC5_ES2  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A)    && \
                                    (CYDEV_CHIP_REVISION_USED > CYDEV_CHIP_REVISION_5A_ES1))
                                    

/***************************************
*       Type defines
***************************************/

/* Sleep Mode API Support */
typedef struct OVComp_backupStruct
{
    uint8 enableState;         
}OVComp_backupStruct;


/**************************************
*        Function Prototypes 
**************************************/

void    OVComp_Start(void);
void    OVComp_Stop(void)               ;
void    OVComp_SetSpeed(uint8 speed)    ;
uint8   OVComp_GetCompare(void)         ;
uint16  OVComp_ZeroCal(void)            ;
void    OVComp_LoadTrim(uint16 trimVal) ;
void OVComp_Init(void)                  ; 
void OVComp_Enable(void)                ;
void OVComp_SaveConfig(void);
void OVComp_RestoreConfig(void);
void OVComp_Sleep(void);
void OVComp_Wakeup(void)                ;
void OVComp_PwrDwnOverrideEnable(void) ;
void OVComp_PwrDwnOverrideDisable(void) ;


/**************************************
*           API Constants        
**************************************/

/* Power constants for SetSpeed() function */
#define OVComp_SLOWSPEED   0x00u
#define OVComp_HIGHSPEED   0x01u
#define OVComp_LOWPOWER    0x02u


/***************************************
*         Trim Locations               
****************************************/

#define OVComp_HS_TRIM_TR0    (CY_GET_XTND_REG8(OVComp_ctComp__TRIM__TR0_HS))
#define OVComp_HS_TRIM_TR1    (CY_GET_XTND_REG8(OVComp_ctComp__TRIM__TR1_HS))


/**************************************
*           Parameter Defaults        
**************************************/

#define OVComp_DEFAULT_SPEED       0u 
#define OVComp_DEFAULT_HYSTERESIS  1u
#define OVComp_DEFAULT_POLARITY    0u
#define OVComp_DEFAULT_BYPASS_SYNC 1u
#define OVComp_DEFAULT_PWRDWN_OVRD 0u

/**************************************
*             Registers        
**************************************/

#define OVComp_CR      (* (reg8 *) OVComp_ctComp__CR )   /* Config register   */
#define OVComp_CR_PTR  (  (reg8 *) OVComp_ctComp__CR )
#define OVComp_CLK     (* (reg8 *) OVComp_ctComp__CLK )  /* Comp clock comtrol register */
#define OVComp_CLK_PTR (  (reg8 *) OVComp_ctComp__CLK )
#define OVComp_SW0     (* (reg8 *) OVComp_ctComp__SW0 )  /* Routing registers */
#define OVComp_SW0_PTR (  (reg8 *) OVComp_ctComp__SW0 )
#define OVComp_SW2     (* (reg8 *) OVComp_ctComp__SW2 )
#define OVComp_SW2_PTR (  (reg8 *) OVComp_ctComp__SW2 )
#define OVComp_SW3     (* (reg8 *) OVComp_ctComp__SW3 )
#define OVComp_SW3_PTR (  (reg8 *) OVComp_ctComp__SW3 )
#define OVComp_SW4     (* (reg8 *) OVComp_ctComp__SW4 )
#define OVComp_SW4_PTR (  (reg8 *) OVComp_ctComp__SW4 )
#define OVComp_SW6     (* (reg8 *) OVComp_ctComp__SW6 )
#define OVComp_SW6_PTR (  (reg8 *) OVComp_ctComp__SW6 )

/* Trim registers */
/* PSoC3 ES2 or early, PSoC5 ES1 or early */
#if (OVComp_PSOC3_ES2 || OVComp_PSOC5_ES1)
    #define OVComp_TR      (* (reg8 *) OVComp_ctComp__TR )   /* Trim registers */
    #define OVComp_TR_PTR  (  (reg8 *) OVComp_ctComp__TR )
#endif

/* PSoC3 ES3 or later, PSoC5 ES2 or later */
#if (OVComp_PSOC3_ES3 || OVComp_PSOC5_ES2) 
    #define OVComp_TR0         (* (reg8 *) OVComp_ctComp__TR0 ) /* Trim register for P-type load */
    #define OVComp_TR0_PTR     (  (reg8 *) OVComp_ctComp__TR0 ) 
    #define OVComp_TR1         (* (reg8 *) OVComp_ctComp__TR1 ) /* Trim register for N-type load */
    #define OVComp_TR1_PTR     (  (reg8 *) OVComp_ctComp__TR1 ) 
#endif

#define OVComp_WRK             (* (reg8 *) OVComp_ctComp__WRK )  /* Working register - output */
#define OVComp_WRK_PTR         (  (reg8 *) OVComp_ctComp__WRK )
#define OVComp_PWRMGR          (* (reg8 *) OVComp_ctComp__PM_ACT_CFG )  /* Active Power manager */
#define OVComp_PWRMGR_PTR      ( (reg8 *) OVComp_ctComp__PM_ACT_CFG )
#define OVComp_STBY_PWRMGR     (* (reg8 *) OVComp_ctComp__PM_STBY_CFG )  /* Standby Power manager */
#define OVComp_STBY_PWRMGR_PTR ( (reg8 *) OVComp_ctComp__PM_STBY_CFG )


/**************************************
*       Register Constants        
**************************************/

/* CR (Comp Control Register)             */
#define OVComp_CFG_MODE_MASK  0x78u
#define OVComp_FILTER_ON      0x40u
#define OVComp_HYST_OFF       0x20u
#define OVComp_CAL_ON         0x10u
#define OVComp_MX_AO          0x08u
#define OVComp_PWRDWN_OVRD    0x04u

#define OVComp_PWR_MODE_SHIFT 0x00u
#define OVComp_PWR_MODE_MASK  (0x03u << OVComp_PWR_MODE_SHIFT)
#define OVComp_PWR_MODE_SLOW  (0x00u << OVComp_PWR_MODE_SHIFT)
#define OVComp_PWR_MODE_FAST  (0x01u << OVComp_PWR_MODE_SHIFT)
#define OVComp_PWR_MODE_ULOW  (0x02u << OVComp_PWR_MODE_SHIFT)

/* CLK (Comp Clock Control Register)      */
#define OVComp_BYPASS_SYNC    0x10u
#define OVComp_SYNC_CLK_EN    0x08u
#define OVComp_SYNCCLK_MASK   (OVComp_BYPASS_SYNC | OVComp_SYNC_CLK_EN)

/* SW3Routing Register definitions */
#define OVComp_CMP_SW3_INPCTL_MASK    0x09u   /* SW3 bits for inP routing control */

/* TR (Comp Trim Register)     */
#define OVComp_DEFAULT_CMP_TRIM  0x00u

/* PSoC3 ES2 or early, PSoC5 ES1 or early */
#if (OVComp_PSOC3_ES2 || OVComp_PSOC5_ES1)
    #define OVComp_CMP_TRIM1_DIR  0x08u   /* Trim direction for N-type load for offset calibration */
    #define OVComp_CMP_TRIM1_MASK 0x07u   /* Trim for N-type load for offset calibration */
    #define OVComp_CMP_TRIM2_DIR  0x80u   /* Trim direction for P-type load for offset calibration */
    #define OVComp_CMP_TRIM2_MASK 0x70u   /* Trim for P-type load for offset calibration */
#endif

/* PSoC3 ES3 or later, PSoC5 ES2 or later */
#if (OVComp_PSOC3_ES3 || OVComp_PSOC5_ES2)
    #define OVComp_CMP_TR0_DIR 0x11u    /* Trim direction for N-type load for offset calibration */
    #define OVComp_CMP_TR0_MASK 0x1Fu   /* Trim for N-type load for offset calibration */
    #define OVComp_CMP_TR1_DIR 0x10u    /* Trim direction for P-type load for offset calibration */
    #define OVComp_CMP_TR1_MASK 0x1Fu   /* Trim for P-type load for offset calibration */ 
#endif


/* WRK (Comp output working register)     */ 
#define OVComp_CMP_OUT_MASK   OVComp_ctComp__WRK_MASK /* Specific comparator out mask */

/* PM_ACT_CFG7 (Active Power Mode CFG Register)     */ 
#define OVComp_ACT_PWR_EN     OVComp_ctComp__PM_ACT_MSK /* Power enable mask */

/* PM_STBY_CFG7 (Standby Power Mode CFG Register)     */ 
#define OVComp_STBY_PWR_EN     OVComp_ctComp__PM_STBY_MSK /* Standby Power enable mask */

#endif /* CY_COMP_OVComp_H */


/* [] END OF FILE  */
