/*******************************************************************************
* File Name: OVComp_PM.c  
* Version 1.60
*
*  Description:
*     This file provides the power management source code to API for the
*     Comparator.  
*
*   Note:
*     None
*
*******************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/


#include "OVComp.h"

static OVComp_backupStruct OVComp_backup;


/*******************************************************************************
* Function Name: OVComp_SaveConfig
********************************************************************************
*
* Summary:
*     Save the current user configuration
*
* Parameters:  
*  void:  
*
* Return: 
*  void
*
* Reentrant:
*  No
*
*******************************************************************************/
void OVComp_SaveConfig(void)
{
    /* Empty since all are system reset for retention flops */
}


/*******************************************************************************
* Function Name: OVComp_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Reentrant:
*  No
*
*******************************************************************************/
void OVComp_RestoreConfig(void)
{
    /* Empty since all are system reset for retention flops */    
}


/*******************************************************************************
* Function Name: OVComp_Sleep
********************************************************************************
*
* Summary:
*     Stop and Save the user configuration
*
* Parameters:  
*  void:  
*
* Return: 
*  void
*
* Global variables:
*  OVComp_backup.enableState:  Is modified depending on the enable state
*  of the block before entering sleep mode.
*
* Reentrant:
*  No
*
*******************************************************************************/
void OVComp_Sleep(void)
{
    /* Save Comp's enable state */    
    if(OVComp_ACT_PWR_EN == (OVComp_PWRMGR & OVComp_ACT_PWR_EN))
    {
        /* Comp is enabled */
        OVComp_backup.enableState = 1u;
    }
    else
    {
        /* Comp is disabled */
        OVComp_backup.enableState = 0u;
    }    
    
    OVComp_Stop();
    OVComp_SaveConfig();
}


/*******************************************************************************
* Function Name: OVComp_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  OVComp_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void OVComp_Wakeup(void) 
{
    OVComp_RestoreConfig();
    
    if(OVComp_backup.enableState == 1u)
    {
        /* Enable Comp's operation */
        OVComp_Enable();

    } /* Do nothing if Comp was disabled before */    
    
}


/* [] END OF FILE */
