/*******************************************************************************
* File Name: TimeOutClock.h
* Version 1.50
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_CLOCK_TimeOutClock_H)
#define CY_CLOCK_TimeOutClock_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
*        Function Prototypes
***************************************/

void TimeOutClock_Start(void) ;
void TimeOutClock_Stop(void) ;

#if(!(CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3 && \
    CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_3A_ES2) && \
	!(CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC5 && \
	CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_5A_ES1))
void TimeOutClock_StopBlock(void) ;
#endif

void TimeOutClock_StandbyPower(uint8 state) ;
void TimeOutClock_SetDividerRegister(uint16 clkDivider, uint8 reset) ;
uint16 TimeOutClock_GetDividerRegister(void) ;
void TimeOutClock_SetModeRegister(uint8 modeBitMask) ;
void TimeOutClock_ClearModeRegister(uint8 modeBitMask) ;
uint8 TimeOutClock_GetModeRegister(void) ;
void TimeOutClock_SetSourceRegister(uint8 clkSource) ;
uint8 TimeOutClock_GetSourceRegister(void) ;
#if defined(TimeOutClock__CFG3)
void TimeOutClock_SetPhaseRegister(uint8 clkPhase) ;
uint8 TimeOutClock_GetPhaseRegister(void) ;
#endif

#define TimeOutClock_Enable()                       TimeOutClock_Start()
#define TimeOutClock_Disable()                      TimeOutClock_Stop()
#define TimeOutClock_SetDivider(clkDivider)         TimeOutClock_SetDividerRegister(clkDivider, 1)
#define TimeOutClock_SetDividerValue(clkDivider)    TimeOutClock_SetDividerRegister((clkDivider) - 1, 1)
#define TimeOutClock_SetMode(clkMode)               TimeOutClock_SetModeRegister(clkMode)
#define TimeOutClock_SetSource(clkSource)           TimeOutClock_SetSourceRegister(clkSource)
#if defined(TimeOutClock__CFG3)
#define TimeOutClock_SetPhase(clkPhase)             TimeOutClock_SetPhaseRegister(clkPhase)
#define TimeOutClock_SetPhaseValue(clkPhase)        TimeOutClock_SetPhaseRegister((clkPhase) + 1)
#endif


/***************************************
*           API Constants
***************************************/

/* Constants SetPhase(), clkPhase parameter. Only valid for PSoC 3 ES2 and earlier. See datasheet for details. */
#if CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3 && \
   (CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_3A_ES1 || \
    CYDEV_CHIP_REVISION_USED == CYDEV_CHIP_REVISION_3A_ES2)
#define CYCLK_2_5NS             0x01 /* 2.5 ns delay. */
#define CYCLK_3_5NS             0x02 /* 3.5 ns delay. */
#define CYCLK_4_5NS             0x03 /* 4.5 ns delay. */
#define CYCLK_5_5NS             0x04 /* 5.5 ns delay. */
#define CYCLK_6_5NS             0x05 /* 6.5 ns delay. */
#define CYCLK_7_5NS             0x06 /* 7.5 ns delay. */
#define CYCLK_8_5NS             0x07 /* 8.5 ns delay. */
#define CYCLK_9_5NS             0x08 /* 9.5 ns delay. */
#define CYCLK_10_5NS            0x09 /* 10.5 ns delay. */
#define CYCLK_11_5NS            0x0A /* 11.5 ns delay. */
#define CYCLK_12_5NS            0x0B /* 12.5 ns delay. */
#endif


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define TimeOutClock_CLKEN              (* (reg8 *) TimeOutClock__PM_ACT_CFG)
#define TimeOutClock_CLKEN_PTR          ((reg8 *) TimeOutClock__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define TimeOutClock_CLKSTBY            (* (reg8 *) TimeOutClock__PM_STBY_CFG)
#define TimeOutClock_CLKSTBY_PTR        ((reg8 *) TimeOutClock__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define TimeOutClock_DIV_LSB            (* (reg8 *) TimeOutClock__CFG0)
#define TimeOutClock_DIV_LSB_PTR        ((reg8 *) TimeOutClock__CFG0)
#define TimeOutClock_DIV_PTR            ((reg16 *) TimeOutClock__CFG0)

/* Clock MSB divider configuration register. */
#define TimeOutClock_DIV_MSB            (* (reg8 *) TimeOutClock__CFG1)
#define TimeOutClock_DIV_MSB_PTR        ((reg8 *) TimeOutClock__CFG1)

/* Mode and source configuration register */
#define TimeOutClock_MOD_SRC            (* (reg8 *) TimeOutClock__CFG2)
#define TimeOutClock_MOD_SRC_PTR        ((reg8 *) TimeOutClock__CFG2)

#if defined(TimeOutClock__CFG3)
/* Analog clock phase configuration register */
#define TimeOutClock_PHASE              (* (reg8 *) TimeOutClock__CFG3)
#define TimeOutClock_PHASE_PTR          ((reg8 *) TimeOutClock__CFG3)
#endif


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define TimeOutClock_CLKEN_MASK         TimeOutClock__PM_ACT_MSK
#define TimeOutClock_CLKSTBY_MASK       TimeOutClock__PM_STBY_MSK

/* CFG2 field masks */
#define TimeOutClock_SRC_SEL_MSK        TimeOutClock__CFG2_SRC_SEL_MASK
#define TimeOutClock_MODE_MASK          (~(TimeOutClock_SRC_SEL_MSK))

#if defined(TimeOutClock__CFG3)
/* CFG3 phase mask */
#define TimeOutClock_PHASE_MASK         TimeOutClock__CFG3_PHASE_DLY_MASK
#endif

#endif /* CY_CLOCK_TimeOutClock_H */


/* [] END OF FILE */
