/*******************************************************************************
* File Name: DitheredPWM_1_PrISM.h
* Version 2.10
*
* Description:
*  This file provides constants and parameter values for the PrISM
*  Component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/


#if !defined(CY_PrISM_DitheredPWM_1_PrISM_H)    /* CY_PrISM_DitheredPWM_1_PrISM_H */
#define CY_PrISM_DitheredPWM_1_PrISM_H

#include "CyLib.h"
#include "cytypes.h"
#include "cyfitter.h"


/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component PrISM_v2_10 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */


/***************************************
*    Initial Parameter Constants
***************************************/
                                     
#define DitheredPWM_1_PrISM_RESOLUTION             (8u)
#define DitheredPWM_1_PrISM_PULSE_TYPE_HARDCODED   (0u)


/***************************************
*       Type defines
***************************************/

/* Sleep Mode API Support */
typedef struct _DitheredPWM_1_PrISM_backupStruct
{
    uint8 enableState;
    #if(!DitheredPWM_1_PrISM_PULSE_TYPE_HARDCODED)
        uint8 cr;
    #endif /* End DitheredPWM_1_PrISM_PULSE_TYPE_HARDCODED */
    uint8 seed;
    uint8 seed_copy;
    uint8 polynom;
    #if(CY_UDB_V0)
        uint8 density0;
        uint8 density1;
    #endif /* End CY_UDB_V0 */
} DitheredPWM_1_PrISM_BACKUP_STRUCT;


/***************************************
*       Function Prototypes
***************************************/

void DitheredPWM_1_PrISM_Start(void) ;
void DitheredPWM_1_PrISM_Stop(void) ;
void DitheredPWM_1_PrISM_SetPulse0Mode(uint8 pulse0Type) ;
void DitheredPWM_1_PrISM_SetPulse1Mode(uint8 pulse1Type) ;
uint8 DitheredPWM_1_PrISM_ReadSeed(void) ;
void DitheredPWM_1_PrISM_WriteSeed(uint8 seed) ;
uint8 DitheredPWM_1_PrISM_ReadPolynomial(void) ;
void DitheredPWM_1_PrISM_WritePolynomial(uint8 polynomial) \
                                                                ;
uint8 DitheredPWM_1_PrISM_ReadPulse0(void) ;
void DitheredPWM_1_PrISM_WritePulse0(uint8 pulseDensity0) \
                                                                ;
uint8 DitheredPWM_1_PrISM_ReadPulse1(void) ;
void DitheredPWM_1_PrISM_WritePulse1(uint8 pulseDensity1) \
                                                                ;
void DitheredPWM_1_PrISM_Sleep(void) ;
void DitheredPWM_1_PrISM_Wakeup(void) ;
void DitheredPWM_1_PrISM_SaveConfig(void) ;
void DitheredPWM_1_PrISM_RestoreConfig(void) ;
void DitheredPWM_1_PrISM_Enable(void) ;
void DitheredPWM_1_PrISM_Init(void) ;


/***************************************
*          API Constants
***************************************/

/* Constants for SetPulse0Mode(), SetPulse1Mode(), pulse type */
#define DitheredPWM_1_PrISM_LESSTHAN_OR_EQUAL      (0x00u)
#define DitheredPWM_1_PrISM_GREATERTHAN_OR_EQUAL   (0x01u)


/***************************************
*    Initial Parameter Constants
***************************************/

#define DitheredPWM_1_PrISM_POLYNOM                (0xB8u)
#define DitheredPWM_1_PrISM_SEED                   (0xFFu)
#define DitheredPWM_1_PrISM_DENSITY0               (0x1u)
#define DitheredPWM_1_PrISM_DENSITY1               (0x1u)


/***************************************
*              Registers
***************************************/

#if (DitheredPWM_1_PrISM_RESOLUTION  <= 8u) /* 8bit - PrISM */
    #define DitheredPWM_1_PrISM_DENSITY0_REG       (* (reg8 *) DitheredPWM_1_PrISM_sC8_PrISMdp_u0__D0_REG)
    #define DitheredPWM_1_PrISM_DENSITY0_PTR       (  (reg8 *) DitheredPWM_1_PrISM_sC8_PrISMdp_u0__D0_REG)
    #define DitheredPWM_1_PrISM_DENSITY1_REG       (* (reg8 *) DitheredPWM_1_PrISM_sC8_PrISMdp_u0__D1_REG)
    #define DitheredPWM_1_PrISM_DENSITY1_PTR       (  (reg8 *) DitheredPWM_1_PrISM_sC8_PrISMdp_u0__D1_REG)
    #define DitheredPWM_1_PrISM_POLYNOM_REG        (* (reg8 *) DitheredPWM_1_PrISM_sC8_PrISMdp_u0__A1_REG)
    #define DitheredPWM_1_PrISM_POLYNOM_PTR        (  (reg8 *) DitheredPWM_1_PrISM_sC8_PrISMdp_u0__A1_REG)
    #define DitheredPWM_1_PrISM_SEED_REG           (* (reg8 *) DitheredPWM_1_PrISM_sC8_PrISMdp_u0__A0_REG)
    #define DitheredPWM_1_PrISM_SEED_PTR           (  (reg8 *) DitheredPWM_1_PrISM_sC8_PrISMdp_u0__A0_REG)
    #define DitheredPWM_1_PrISM_SEED_COPY_REG      (* (reg8 *) DitheredPWM_1_PrISM_sC8_PrISMdp_u0__F0_REG)
    #define DitheredPWM_1_PrISM_SEED_COPY_PTR      (  (reg8 *) DitheredPWM_1_PrISM_sC8_PrISMdp_u0__F0_REG)
    #define DitheredPWM_1_PrISM_AUX_CONTROL_REG    (* (reg8 *) DitheredPWM_1_PrISM_sC8_PrISMdp_u0__DP_AUX_CTL_REG)
    #define DitheredPWM_1_PrISM_AUX_CONTROL_PTR    (  (reg8 *) DitheredPWM_1_PrISM_sC8_PrISMdp_u0__DP_AUX_CTL_REG)
#elif (DitheredPWM_1_PrISM_RESOLUTION <= 16u) /* 16bit - PrISM */
    #define DitheredPWM_1_PrISM_DENSITY0_PTR       ((reg16 *) DitheredPWM_1_PrISM_sC16_PrISMdp_u0__D0_REG)
    #define DitheredPWM_1_PrISM_DENSITY1_PTR       ((reg16 *) DitheredPWM_1_PrISM_sC16_PrISMdp_u0__D1_REG)
    #define DitheredPWM_1_PrISM_POLYNOM_PTR        ((reg16 *) DitheredPWM_1_PrISM_sC16_PrISMdp_u0__A1_REG)
    #define DitheredPWM_1_PrISM_SEED_PTR           ((reg16 *) DitheredPWM_1_PrISM_sC16_PrISMdp_u0__A0_REG)
    #define DitheredPWM_1_PrISM_SEED_COPY_PTR      ((reg16 *) DitheredPWM_1_PrISM_sC16_PrISMdp_u0__F0_REG)
    #define DitheredPWM_1_PrISM_AUX_CONTROL_PTR    ((reg16 *) DitheredPWM_1_PrISM_sC16_PrISMdp_u0__DP_AUX_CTL_REG)
#elif (DitheredPWM_1_PrISM_RESOLUTION <= 24u) /* 24bit - PrISM */
    #define DitheredPWM_1_PrISM_DENSITY0_PTR       ((reg32 *) DitheredPWM_1_PrISM_sC24_PrISMdp_u0__D0_REG)
    #define DitheredPWM_1_PrISM_DENSITY1_PTR       ((reg32 *) DitheredPWM_1_PrISM_sC24_PrISMdp_u0__D1_REG)
    #define DitheredPWM_1_PrISM_POLYNOM_PTR        ((reg32 *) DitheredPWM_1_PrISM_sC24_PrISMdp_u0__A1_REG)
    #define DitheredPWM_1_PrISM_SEED_PTR           ((reg32 *) DitheredPWM_1_PrISM_sC24_PrISMdp_u0__A0_REG)
    #define DitheredPWM_1_PrISM_SEED_COPY_PTR      ((reg32 *) DitheredPWM_1_PrISM_sC24_PrISMdp_u0__F0_REG)
    #define DitheredPWM_1_PrISM_AUX_CONTROL_PTR    ((reg32 *) DitheredPWM_1_PrISM_sC24_PrISMdp_u0__DP_AUX_CTL_REG)
    #define DitheredPWM_1_PrISM_AUX_CONTROL2_PTR   ((reg32 *) DitheredPWM_1_PrISM_sC24_PrISMdp_u2__DP_AUX_CTL_REG)
#else /* 32bit - PrISM */
    #define DitheredPWM_1_PrISM_DENSITY0_PTR       ((reg32 *) DitheredPWM_1_PrISM_sC32_PrISMdp_u0__D0_REG)
    #define DitheredPWM_1_PrISM_DENSITY1_PTR       ((reg32 *) DitheredPWM_1_PrISM_sC32_PrISMdp_u0__D1_REG)
    #define DitheredPWM_1_PrISM_POLYNOM_PTR        ((reg32 *) DitheredPWM_1_PrISM_sC32_PrISMdp_u0__A1_REG)
    #define DitheredPWM_1_PrISM_SEED_PTR           ((reg32 *) DitheredPWM_1_PrISM_sC32_PrISMdp_u0__A0_REG)
    #define DitheredPWM_1_PrISM_SEED_COPY_PTR      ((reg32 *) DitheredPWM_1_PrISM_sC32_PrISMdp_u0__F0_REG)
    #define DitheredPWM_1_PrISM_AUX_CONTROL_PTR    ((reg32 *) DitheredPWM_1_PrISM_sC32_PrISMdp_u0__DP_AUX_CTL_REG)
    #define DitheredPWM_1_PrISM_AUX_CONTROL2_PTR   ((reg32 *) DitheredPWM_1_PrISM_sC32_PrISMdp_u2__DP_AUX_CTL_REG)
#endif /* End DitheredPWM_1_PrISM_RESOLUTION */

#define DitheredPWM_1_PrISM_CONTROL_REG   (* (reg8 *) DitheredPWM_1_PrISM_SyncCtl_ControlReg__CONTROL_REG)
#define DitheredPWM_1_PrISM_CONTROL_PTR   (  (reg8 *) DitheredPWM_1_PrISM_SyncCtl_ControlReg__CONTROL_REG)


/***************************************
*       Register Constants
***************************************/

#define DitheredPWM_1_PrISM_CTRL_ENABLE                                (0x01u)
#define DitheredPWM_1_PrISM_CTRL_COMPARE_TYPE0_GREATER_THAN_OR_EQUAL   (0x02u)
#define DitheredPWM_1_PrISM_CTRL_COMPARE_TYPE1_GREATER_THAN_OR_EQUAL   (0x04u)

#define DitheredPWM_1_PrISM_FIFO0_CLR                                  (0x01u)


/***************************************
* Renamed global variables or defines 
* for backward compatible
***************************************/
#define DitheredPWM_1_PrISM_ReadPusle0     DitheredPWM_1_PrISM_ReadPulse0
#define DitheredPWM_1_PrISM_ReadPusle1     DitheredPWM_1_PrISM_ReadPulse1


#endif  /* End CY_PrISM_DitheredPWM_1_PrISM_H */


/* [] END OF FILE */
