/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/

#if !defined LiIonCharger_H
#define LiIonCharger_H

#include "device.h"

/* macros */

/* ADC */
#define ADC_MR 4096   /* ADC measrurement range * 1000 */ 
#define ADC_RS 65536  /* ADC resolution */

/* Battery Charging PWM duty cycle step sizes */
#define PWM_InitStep    0
#define PWM_ActStep     1
#define PWM_RapidStep   1
#define PWM_ConstStep   1
#define PWM_ZeroStep    0

/* Hysteresis for parameter control */
#define Curr_ActDiff     20
#define Curr_RapidDiff   50
#define Volt_ConstDiff   50

/* Battery Charging State */
#define BATTERY_INIT    0x30
#define ACTIVATION      0x31
#define RAPID_CHARGE    0x32
#define CONST_VOLTAGE   0x33
#define WAIT_FOR_TEMP   0x34
#define NO_BATTERY      0x35
#define CHARGE_COMPLETE 0x36
#define BATTERY_ERROR   0x37

/* Error States */
#define ER_NO_ERROR		    0x30
#define ER_OVER_VOLTAGE	    0x31
#define ER_OVER_CURRENT 	0x32
#define ER_ACTIVE_TIMEOUT	0x33
#define ER_RAPID_TIMEOUT	0x34
#define ER_FULL_TIMEOUT	    0x35
#define ER_START_TIMEOUT	0x36
#define ER_TEMP_ERROR		0x37
#define ER_CV_TIMEOUT		0x38

/* User Adjustable timeouts - In multiples of the timer clock (currently 2 Hz) */
#define TIME_OUT_FREQ 					2    //Hz
#define MIN_TO_SEC						60
#define ACT_TO_RAPID_TIME_LIMIT 		70 * MIN_TO_SEC * TIME_OUT_FREQ     //70min
#define RAPID_CHARGE_TIME_LIMIT 		80 * MIN_TO_SEC * TIME_OUT_FREQ     //80min  
#define CONST_VOLTAGE_TIME_LIMIT 		120 * MIN_TO_SEC * TIME_OUT_FREQ     //120min
#define ACT_TIME_LIMIT 					20 * TIME_OUT_FREQ			//20sec
#define TERMINATE_CHARGE_TIME 			10 * TIME_OUT_FREQ			//10sec   

/* Battery Charging profile constants */
#define ACT_START_VOLTAGE 2800              //mV
#define RAPID_CHARGE_START_VOLTAGE 3000     //mV
#define FULL_CHARGE_VOLTAGE 4200            //mV
#define RECHARGE_VOLTAGE 4100               //mV
#define TERMINATION_CURRENT 30 * 0.2/(ADC_MR)*ADC_RS  /* ADC counts for 30mA termination current through 0.2ohm sense resistor */ 
#define EMERGENCY_CHARGE_STOP_VOLTAGE 4350  //mV
#define EMERGENCY_CHARGE_STOP_CURRENT 1200 * 0.2/(ADC_MR)*ADC_RS /* ADC counts for 1A charge stop current through 0.2ohm sense resistor */
#define ACTIVATION_CURRENT   60 * 0.2/(ADC_MR)*ADC_RS /* ADC counts for 60mA activation current through 0.2ohm sense resistor */
#define RAPID_CHARGE_CURRENT 1000* 0.2/(ADC_MR)*ADC_RS  /* ADC counts for 900mA Rapid charge current through 0.2ohm sense resistor */


#define TCOLD_STOP      2*100    //2degC
#define TCOLD_RESTART   3*100    //3degC   
#define THOT_STOP       50*100   //50degC
#define THOT_RESTART    48*100   //48degC 
#define ROPEN           35       //35Kohm- thermistor open indication 


/* AMUX_ADC select channels */
#define BAT_VOLTAGE     0x0
#define BAT_CURRENT     0x1
#define BAT_TEMP_1      0x2
#define BAT_TEMP_2      0x3
#define CALIBRATION_ADC 0x4
#define ADC_OFFSET      0x5
   
/* AMUX_VDAC channels */
#define CALIBRATION_VDAC    0x0
#define THERMISTOR          0x1
   
/* Timer States */
#define ON  0x1
#define OFF 0x0

/* PWM Duty Limits */
#define HILIMIT 0x1600   /* 45% duty cycle */
#define LOLIMIT 256      /* 2% duty cycle */  

/* Variables */
extern uint8 ErrorState;
extern uint8 BatteryState;
extern int16 VBat;
extern int16 TBat;
extern int16 IBat;
extern int16 VADCSamples[16];
extern int16 IADCSamples[16];
extern int16 ADCOffset;
extern uint8 TimerState;
extern uint8 TimeOut;
extern uint8 ChargingState;
extern uint16 PWMDuty;
extern float Scale;
extern uint8 StatusFlags;

//thresholds
extern uint16 ActivationStartVoltage;
extern uint16 RapidChargeStartVoltage;
extern uint16 FullChargeVoltage;
extern uint16 RechargeVoltage;
extern uint8 TerminationCurrent;
extern uint8 EmergStopCurrent;
extern uint16 EmergStopVoltage;
extern uint8 ActivationCurrent;
extern uint16 RapidChargeCurrent;
extern uint8 Fault;

/* functions */
int16 ReadADC(void);
void UpdateBatteryState(void);
void GetBatteryVoltage(void);
void GetBatteryCurrent(void);
void GetBatteryTemperature(void);
void GetADCOffset(void);
void UpdateControlLoop(void);
void GetScalingFactor(void);
void CalculateThresholds(void);
void ChargerStart(void);
void StoreScaleFactor(void);


#endif

//[] END OF FILE
