/*******************************************************************************
* File Name: DitheredPWM_1_PWM_PM.c
* Version 2.20
*
* Description:
*  This file provides the power management source code to API for the
*  PWM.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/
#include "cytypes.h"
#include "DitheredPWM_1_PWM.h"

static DitheredPWM_1_PWM_backupStruct DitheredPWM_1_PWM_backup;


/*******************************************************************************
* Function Name: DitheredPWM_1_PWM_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration of the component.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  DitheredPWM_1_PWM_backup:  Variables of this global structure are modified to 
*  store the values of non retention configuration registers when Sleep() API is 
*  called.
*
*******************************************************************************/
void DitheredPWM_1_PWM_SaveConfig(void) 
{
    
    #if(!DitheredPWM_1_PWM_UsingFixedFunction)
        #if (CY_PSOC5A)
            DitheredPWM_1_PWM_backup.PWMUdb = DitheredPWM_1_PWM_ReadCounter();
            DitheredPWM_1_PWM_backup.PWMPeriod = DitheredPWM_1_PWM_ReadPeriod();
            #if (DitheredPWM_1_PWM_UseStatus)
                DitheredPWM_1_PWM_backup.InterruptMaskValue = DitheredPWM_1_PWM_STATUS_MASK;
            #endif /* (DitheredPWM_1_PWM_UseStatus) */
            
            #if(DitheredPWM_1_PWM_UseOneCompareMode)
                DitheredPWM_1_PWM_backup.PWMCompareValue = DitheredPWM_1_PWM_ReadCompare();
            #else
                DitheredPWM_1_PWM_backup.PWMCompareValue1 = DitheredPWM_1_PWM_ReadCompare1();
                DitheredPWM_1_PWM_backup.PWMCompareValue2 = DitheredPWM_1_PWM_ReadCompare2();
            #endif /* (DitheredPWM_1_PWM_UseOneCompareMode) */
            
           #if(DitheredPWM_1_PWM_DeadBandUsed)
                DitheredPWM_1_PWM_backup.PWMdeadBandValue = DitheredPWM_1_PWM_ReadDeadTime();
            #endif /* (DitheredPWM_1_PWM_DeadBandUsed) */
          
            #if ( DitheredPWM_1_PWM_KillModeMinTime)
                DitheredPWM_1_PWM_backup.PWMKillCounterPeriod = DitheredPWM_1_PWM_ReadKillTime();
            #endif /* ( DitheredPWM_1_PWM_KillModeMinTime) */
        #endif /* (CY_PSOC5A) */
        
        #if (CY_PSOC3 || CY_PSOC5LP)
            #if(!DitheredPWM_1_PWM_PWMModeIsCenterAligned)
                DitheredPWM_1_PWM_backup.PWMPeriod = DitheredPWM_1_PWM_ReadPeriod();
            #endif /* (!DitheredPWM_1_PWM_PWMModeIsCenterAligned) */
            DitheredPWM_1_PWM_backup.PWMUdb = DitheredPWM_1_PWM_ReadCounter();
            #if (DitheredPWM_1_PWM_UseStatus)
                DitheredPWM_1_PWM_backup.InterruptMaskValue = DitheredPWM_1_PWM_STATUS_MASK;
            #endif /* (DitheredPWM_1_PWM_UseStatus) */
            
            #if(DitheredPWM_1_PWM_DeadBandMode == DitheredPWM_1_PWM__B_PWM__DBM_256_CLOCKS || \
                DitheredPWM_1_PWM_DeadBandMode == DitheredPWM_1_PWM__B_PWM__DBM_2_4_CLOCKS)
                DitheredPWM_1_PWM_backup.PWMdeadBandValue = DitheredPWM_1_PWM_ReadDeadTime();
            #endif /*  deadband count is either 2-4 clocks or 256 clocks */
            
            #if(DitheredPWM_1_PWM_KillModeMinTime)
                 DitheredPWM_1_PWM_backup.PWMKillCounterPeriod = DitheredPWM_1_PWM_ReadKillTime();
            #endif /* (DitheredPWM_1_PWM_KillModeMinTime) */
        #endif /* (CY_PSOC3 || CY_PSOC5LP) */
        
        #if(DitheredPWM_1_PWM_UseControl)
            DitheredPWM_1_PWM_backup.PWMControlRegister = DitheredPWM_1_PWM_ReadControlRegister();
        #endif /* (DitheredPWM_1_PWM_UseControl) */
    #endif  /* (!DitheredPWM_1_PWM_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: DitheredPWM_1_PWM_RestoreConfig
********************************************************************************
* 
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  DitheredPWM_1_PWM_backup:  Variables of this global structure are used to  
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void DitheredPWM_1_PWM_RestoreConfig(void) 
{
        #if(!DitheredPWM_1_PWM_UsingFixedFunction)
            #if (CY_PSOC5A)
                /* Interrupt State Backup for Critical Region*/
                uint8 DitheredPWM_1_PWM_interruptState;
                /* Enter Critical Region*/
                DitheredPWM_1_PWM_interruptState = CyEnterCriticalSection();
                #if (DitheredPWM_1_PWM_UseStatus)
                    /* Use the interrupt output of the status register for IRQ output */
                    DitheredPWM_1_PWM_STATUS_AUX_CTRL |= DitheredPWM_1_PWM_STATUS_ACTL_INT_EN_MASK;
                    
                    DitheredPWM_1_PWM_STATUS_MASK = DitheredPWM_1_PWM_backup.InterruptMaskValue;
                #endif /* (DitheredPWM_1_PWM_UseStatus) */
                
                #if (DitheredPWM_1_PWM_Resolution == 8)
                    /* Set FIFO 0 to 1 byte register for period*/
                    DitheredPWM_1_PWM_AUX_CONTROLDP0 |= (DitheredPWM_1_PWM_AUX_CTRL_FIFO0_CLR);
                #else /* (DitheredPWM_1_PWM_Resolution == 16)*/
                    /* Set FIFO 0 to 1 byte register for period */
                    DitheredPWM_1_PWM_AUX_CONTROLDP0 |= (DitheredPWM_1_PWM_AUX_CTRL_FIFO0_CLR);
                    DitheredPWM_1_PWM_AUX_CONTROLDP1 |= (DitheredPWM_1_PWM_AUX_CTRL_FIFO0_CLR);
                #endif /* (DitheredPWM_1_PWM_Resolution == 8) */
                /* Exit Critical Region*/
                CyExitCriticalSection(DitheredPWM_1_PWM_interruptState);
                
                DitheredPWM_1_PWM_WriteCounter(DitheredPWM_1_PWM_backup.PWMUdb);
                DitheredPWM_1_PWM_WritePeriod(DitheredPWM_1_PWM_backup.PWMPeriod);
                
                #if(DitheredPWM_1_PWM_UseOneCompareMode)
                    DitheredPWM_1_PWM_WriteCompare(DitheredPWM_1_PWM_backup.PWMCompareValue);
                #else
                    DitheredPWM_1_PWM_WriteCompare1(DitheredPWM_1_PWM_backup.PWMCompareValue1);
                    DitheredPWM_1_PWM_WriteCompare2(DitheredPWM_1_PWM_backup.PWMCompareValue2);
                #endif /* (DitheredPWM_1_PWM_UseOneCompareMode) */
                
               #if(DitheredPWM_1_PWM_DeadBandMode == DitheredPWM_1_PWM__B_PWM__DBM_256_CLOCKS || \
                   DitheredPWM_1_PWM_DeadBandMode == DitheredPWM_1_PWM__B_PWM__DBM_2_4_CLOCKS)
                    DitheredPWM_1_PWM_WriteDeadTime(DitheredPWM_1_PWM_backup.PWMdeadBandValue);
                #endif /* deadband count is either 2-4 clocks or 256 clocks */
            
                #if ( DitheredPWM_1_PWM_KillModeMinTime)
                    DitheredPWM_1_PWM_WriteKillTime(DitheredPWM_1_PWM_backup.PWMKillCounterPeriod);
                #endif /* ( DitheredPWM_1_PWM_KillModeMinTime) */
            #endif /* (CY_PSOC5A) */
            
            #if (CY_PSOC3 || CY_PSOC5LP)
                #if(!DitheredPWM_1_PWM_PWMModeIsCenterAligned)
                    DitheredPWM_1_PWM_WritePeriod(DitheredPWM_1_PWM_backup.PWMPeriod);
                #endif /* (!DitheredPWM_1_PWM_PWMModeIsCenterAligned) */
                DitheredPWM_1_PWM_WriteCounter(DitheredPWM_1_PWM_backup.PWMUdb);
                #if (DitheredPWM_1_PWM_UseStatus)
                    DitheredPWM_1_PWM_STATUS_MASK = DitheredPWM_1_PWM_backup.InterruptMaskValue;
                #endif /* (DitheredPWM_1_PWM_UseStatus) */
                
                #if(DitheredPWM_1_PWM_DeadBandMode == DitheredPWM_1_PWM__B_PWM__DBM_256_CLOCKS || \
                    DitheredPWM_1_PWM_DeadBandMode == DitheredPWM_1_PWM__B_PWM__DBM_2_4_CLOCKS)
                    DitheredPWM_1_PWM_WriteDeadTime(DitheredPWM_1_PWM_backup.PWMdeadBandValue);
                #endif /* deadband count is either 2-4 clocks or 256 clocks */
                
                #if(DitheredPWM_1_PWM_KillModeMinTime)
                    DitheredPWM_1_PWM_WriteKillTime(DitheredPWM_1_PWM_backup.PWMKillCounterPeriod);
                #endif /* (DitheredPWM_1_PWM_KillModeMinTime) */
            #endif /* (CY_PSOC3 || CY_PSOC5LP) */
            
            #if(DitheredPWM_1_PWM_UseControl)
                DitheredPWM_1_PWM_WriteControlRegister(DitheredPWM_1_PWM_backup.PWMControlRegister); 
            #endif /* (DitheredPWM_1_PWM_UseControl) */
        #endif  /* (!DitheredPWM_1_PWM_UsingFixedFunction) */
    }


/*******************************************************************************
* Function Name: DitheredPWM_1_PWM_Sleep
********************************************************************************
* 
* Summary:
*  Disables block's operation and saves the user configuration. Should be called 
*  just prior to entering sleep.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  DitheredPWM_1_PWM_backup.PWMEnableState:  Is modified depending on the enable 
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void DitheredPWM_1_PWM_Sleep(void) 
{
    #if(DitheredPWM_1_PWM_UseControl)
        if(DitheredPWM_1_PWM_CTRL_ENABLE == (DitheredPWM_1_PWM_CONTROL & DitheredPWM_1_PWM_CTRL_ENABLE))
        {
            /*Component is enabled */
            DitheredPWM_1_PWM_backup.PWMEnableState = 1u;
        }
        else
        {
            /* Component is disabled */
            DitheredPWM_1_PWM_backup.PWMEnableState = 0u;
        }
    #endif /* (DitheredPWM_1_PWM_UseControl) */
    /* Stop component */
    DitheredPWM_1_PWM_Stop();
    
    /* Save registers configuration */
    DitheredPWM_1_PWM_SaveConfig();
}


/*******************************************************************************
* Function Name: DitheredPWM_1_PWM_Wakeup
********************************************************************************
* 
* Summary:
*  Restores and enables the user configuration. Should be called just after 
*  awaking from sleep.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  DitheredPWM_1_PWM_backup.pwmEnable:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void DitheredPWM_1_PWM_Wakeup(void) 
{
     /* Restore registers values */
    DitheredPWM_1_PWM_RestoreConfig();
    
    if(DitheredPWM_1_PWM_backup.PWMEnableState != 0u)
    {
        /* Enable component's operation */
        DitheredPWM_1_PWM_Enable();
    } /* Do nothing if component's block was disabled before */
    
}


/* [] END OF FILE */
