/*******************************************************************************
* File Name: DitheredPWM_1_PrISM_PM.c
* Version 2.10
*
* Description:
*  This file provides Sleep/WakeUp APIs functionality of the PrISM component
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "DitheredPWM_1_PrISM.h"


/***************************************
* Forward function references
***************************************/
void DitheredPWM_1_PrISM_Enable(void) ;


/***************************************
* Local data allocation
***************************************/
static DitheredPWM_1_PrISM_BACKUP_STRUCT  DitheredPWM_1_PrISM_backup = 
{
    /* enableState */
    0u,
    /* cr */
    #if(!DitheredPWM_1_PrISM_PULSE_TYPE_HARDCODED)
        (DitheredPWM_1_PrISM_GREATERTHAN_OR_EQUAL == 0 ? \
                                                DitheredPWM_1_PrISM_CTRL_COMPARE_TYPE0_GREATER_THAN_OR_EQUAL : 0) |
        (DitheredPWM_1_PrISM_GREATERTHAN_OR_EQUAL == 0 ? \
                                                DitheredPWM_1_PrISM_CTRL_COMPARE_TYPE1_GREATER_THAN_OR_EQUAL : 0),
    #endif /* End DitheredPWM_1_PrISM_PULSE_TYPE_HARDCODED */
    /* seed */    
    DitheredPWM_1_PrISM_SEED,
    /* seed_copy */    
    DitheredPWM_1_PrISM_SEED,
    /* polynom */
    DitheredPWM_1_PrISM_POLYNOM,
    #if(CY_UDB_V0)
        /* density0 */
        DitheredPWM_1_PrISM_DENSITY0,
        /* density1 */
        DitheredPWM_1_PrISM_DENSITY1,
    #endif /*End CY_UDB_V0*/
};


/*******************************************************************************
* Function Name: DitheredPWM_1_PrISM_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration.
*  
* Parameters:  
*  None.
*
* Return: 
*  None.
*
* Global Variables:
*  DitheredPWM_1_PrISM_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void DitheredPWM_1_PrISM_SaveConfig(void) 
{
    #if (CY_UDB_V0)
        #if(!DitheredPWM_1_PrISM_PULSE_TYPE_HARDCODED)
            DitheredPWM_1_PrISM_backup.cr = DitheredPWM_1_PrISM_CONTROL_REG;
        #endif /* End DitheredPWM_1_PrISM_PULSE_TYPE_HARDCODED */
        DitheredPWM_1_PrISM_backup.seed = DitheredPWM_1_PrISM_ReadSeed();
        DitheredPWM_1_PrISM_backup.seed_copy = CY_GET_REG8(DitheredPWM_1_PrISM_SEED_COPY_PTR);
        DitheredPWM_1_PrISM_backup.polynom = DitheredPWM_1_PrISM_ReadPolynomial();
        DitheredPWM_1_PrISM_backup.density0 = DitheredPWM_1_PrISM_ReadPulse0();
        DitheredPWM_1_PrISM_backup.density1 = DitheredPWM_1_PrISM_ReadPulse1();
    #else /* CY_UDB_V1 */
        #if(!DitheredPWM_1_PrISM_PULSE_TYPE_HARDCODED)
            DitheredPWM_1_PrISM_backup.cr = DitheredPWM_1_PrISM_CONTROL_REG;
        #endif /* End DitheredPWM_1_PrISM_PULSE_TYPE_HARDCODED */
        DitheredPWM_1_PrISM_backup.seed = DitheredPWM_1_PrISM_ReadSeed();
        DitheredPWM_1_PrISM_backup.seed_copy = CY_GET_REG8(DitheredPWM_1_PrISM_SEED_COPY_PTR);
        DitheredPWM_1_PrISM_backup.polynom = DitheredPWM_1_PrISM_ReadPolynomial();
    #endif  /* CY_UDB_V0 */
}


/*******************************************************************************
* Function Name: DitheredPWM_1_PrISM_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  None.
*
* Return: 
*  None.
*
* Global Variables:
*  DitheredPWM_1_PrISM_backup - used when non-retention registers are restored.
*
*******************************************************************************/
void DitheredPWM_1_PrISM_RestoreConfig(void) 
{
    #if (CY_UDB_V0)
    
        uint8 enableInterrupts;
        
        #if(!DitheredPWM_1_PrISM_PULSE_TYPE_HARDCODED)
            DitheredPWM_1_PrISM_CONTROL_REG = DitheredPWM_1_PrISM_backup.cr;
        #endif /* End DitheredPWM_1_PrISM_PULSE_TYPE_HARDCODED */

        CY_SET_REG8(DitheredPWM_1_PrISM_SEED_COPY_PTR, DitheredPWM_1_PrISM_backup.seed_copy);
        CY_SET_REG8(DitheredPWM_1_PrISM_SEED_PTR, DitheredPWM_1_PrISM_backup.seed);
        DitheredPWM_1_PrISM_WritePolynomial(DitheredPWM_1_PrISM_backup.polynom);
        DitheredPWM_1_PrISM_WritePulse0(DitheredPWM_1_PrISM_backup.density0);
        DitheredPWM_1_PrISM_WritePulse1(DitheredPWM_1_PrISM_backup.density1);
        
        enableInterrupts = CyEnterCriticalSection();
        /* Set FIFO0_CLR bit to use FIFO0 as a simple one-byte buffer*/
        #if (DitheredPWM_1_PrISM_RESOLUTION <= 8u)      /* 8bit - PrISM */
            DitheredPWM_1_PrISM_AUX_CONTROL_REG |= DitheredPWM_1_PrISM_FIFO0_CLR;
        #elif (DitheredPWM_1_PrISM_RESOLUTION <= 16u)   /* 16bit - PrISM */
            CY_SET_REG16(DitheredPWM_1_PrISM_AUX_CONTROL_PTR, CY_GET_REG16(DitheredPWM_1_PrISM_AUX_CONTROL_PTR) | 
                                            DitheredPWM_1_PrISM_FIFO0_CLR | DitheredPWM_1_PrISM_FIFO0_CLR << 8u);
        #elif (DitheredPWM_1_PrISM_RESOLUTION <= 24)   /* 24bit - PrISM */
            CY_SET_REG24(DitheredPWM_1_PrISM_AUX_CONTROL_PTR, CY_GET_REG24(DitheredPWM_1_PrISM_AUX_CONTROL_PTR) |
                                            DitheredPWM_1_PrISM_FIFO0_CLR | DitheredPWM_1_PrISM_FIFO0_CLR << 8u );
            CY_SET_REG24(DitheredPWM_1_PrISM_AUX_CONTROL2_PTR, CY_GET_REG24(DitheredPWM_1_PrISM_AUX_CONTROL2_PTR) | 
                                            DitheredPWM_1_PrISM_FIFO0_CLR );
        #else                                 /* 32bit - PrISM */
            CY_SET_REG32(DitheredPWM_1_PrISM_AUX_CONTROL_PTR, CY_GET_REG32(DitheredPWM_1_PrISM_AUX_CONTROL_PTR) |
                                            DitheredPWM_1_PrISM_FIFO0_CLR | DitheredPWM_1_PrISM_FIFO0_CLR << 8u );
            CY_SET_REG32(DitheredPWM_1_PrISM_AUX_CONTROL2_PTR, CY_GET_REG32(DitheredPWM_1_PrISM_AUX_CONTROL2_PTR) |
                                            DitheredPWM_1_PrISM_FIFO0_CLR | DitheredPWM_1_PrISM_FIFO0_CLR << 8u );
        #endif                                /* End DitheredPWM_1_PrISM_RESOLUTION */
        CyExitCriticalSection(enableInterrupts);
   
    #else   /* CY_UDB_V1 */

        #if(!DitheredPWM_1_PrISM_PULSE_TYPE_HARDCODED)
            DitheredPWM_1_PrISM_CONTROL_REG = DitheredPWM_1_PrISM_backup.cr;
        #endif /* End DitheredPWM_1_PrISM_PULSE_TYPE_HARDCODED */

        CY_SET_REG8(DitheredPWM_1_PrISM_SEED_COPY_PTR, DitheredPWM_1_PrISM_backup.seed_copy);
        CY_SET_REG8(DitheredPWM_1_PrISM_SEED_PTR, DitheredPWM_1_PrISM_backup.seed);
        DitheredPWM_1_PrISM_WritePolynomial(DitheredPWM_1_PrISM_backup.polynom);
    
    #endif  /* End CY_UDB_V0 */
}


/*******************************************************************************
* Function Name: DitheredPWM_1_PrISM_Sleep
********************************************************************************
*
* Summary:
*  Stops and saves the user configuration
*  
* Parameters:  
*  None.
*
* Return: 
*  None.
*
* Global Variables:
*  DitheredPWM_1_PrISM_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void DitheredPWM_1_PrISM_Sleep(void) 
{
    #if(!DitheredPWM_1_PrISM_PULSE_TYPE_HARDCODED)
        if((DitheredPWM_1_PrISM_CONTROL_REG & DitheredPWM_1_PrISM_CTRL_ENABLE) != 0u) 
        {
            DitheredPWM_1_PrISM_backup.enableState = 1u;
        }
        else
        {
            DitheredPWM_1_PrISM_backup.enableState = 0u;
        }
    #endif /* End DitheredPWM_1_PrISM_PULSE_TYPE_HARDCODED */
    DitheredPWM_1_PrISM_Stop();
    DitheredPWM_1_PrISM_SaveConfig();
}


/*******************************************************************************
* Function Name: DitheredPWM_1_PrISM_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  None.
*
* Return: 
*  None.
*
* Global Variables:
*  DitheredPWM_1_PrISM_backup - used when non-retention registers are restored.
*
*******************************************************************************/
void DitheredPWM_1_PrISM_Wakeup(void) 
{
    DitheredPWM_1_PrISM_RestoreConfig();
    if(DitheredPWM_1_PrISM_backup.enableState != 0u)
    {
        DitheredPWM_1_PrISM_Enable();
    } 
}


/* [] END OF FILE */
