/*******************************************************************************
* File Name: IDAC8_Ref.c
* Version 2.0
*
* Description:
*  This file provides the power management source code to API for the
*  IDAC8.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/


#include "IDAC8_Ref.h"

static IDAC8_Ref_backupStruct IDAC8_Ref_backup;


/*******************************************************************************
* Function Name: IDAC8_Ref_SaveConfig
********************************************************************************
* Summary:
*  Save the current user configuration
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void IDAC8_Ref_SaveConfig(void) 
{
    if (!((IDAC8_Ref_CR1 & IDAC8_Ref_SRC_MASK) == IDAC8_Ref_SRC_UDB))
    {
        IDAC8_Ref_backup.data_value = IDAC8_Ref_Data;
    }
}


/*******************************************************************************
* Function Name: IDAC8_Ref_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  void
*
* Return:
*  void
*
*******************************************************************************/
void IDAC8_Ref_RestoreConfig(void) 
{
    if (!((IDAC8_Ref_CR1 & IDAC8_Ref_SRC_MASK) == IDAC8_Ref_SRC_UDB))
    {
        if((IDAC8_Ref_Strobe & IDAC8_Ref_STRB_MASK) == IDAC8_Ref_STRB_EN)
        {
            IDAC8_Ref_Strobe &= (uint8)(~IDAC8_Ref_STRB_MASK);
            IDAC8_Ref_Data = IDAC8_Ref_backup.data_value;
            IDAC8_Ref_Strobe |= IDAC8_Ref_STRB_EN;
        }
        else
        {
            IDAC8_Ref_Data = IDAC8_Ref_backup.data_value;
        }
    }
}


/*******************************************************************************
* Function Name: IDAC8_Ref_Sleep
********************************************************************************
* Summary:
*  Stop and Save the user configuration
*
* Parameters:
*  void:
*
* Return:
*  void
*
* Global variables:
*  IDAC8_Ref_backup.enableState: Is modified depending on the enable 
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void IDAC8_Ref_Sleep(void) 
{
    if(IDAC8_Ref_ACT_PWR_EN == (IDAC8_Ref_PWRMGR & IDAC8_Ref_ACT_PWR_EN))
    {
        /* IDAC8 is enabled */
        IDAC8_Ref_backup.enableState = 1u;
    }
    else
    {
        /* IDAC8 is disabled */
        IDAC8_Ref_backup.enableState = 0u;
    }

    IDAC8_Ref_Stop();
    IDAC8_Ref_SaveConfig();
}


/*******************************************************************************
* Function Name: IDAC8_Ref_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  IDAC8_Ref_backup.enableState: Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void IDAC8_Ref_Wakeup(void) 
{
    IDAC8_Ref_RestoreConfig();
    
    if(IDAC8_Ref_backup.enableState == 1u)
    {
        /* Enable IDAC8's operation */
        IDAC8_Ref_Enable();
        
        /* Set the data register */
        IDAC8_Ref_SetValue(IDAC8_Ref_Data);
    } /* Do nothing if IDAC8 was disabled before */    
}


/* [] END OF FILE */
