/*******************************************************************************
* File Name: `$INSTANCE_NAME`.c
* Version `$CY_MAJOR_VERSION`.`$CY_MINOR_VERSION`
*
* Description:
*  This file provides the API source code for the Thermistor component.
*
* Note: none
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/
#include "`$INSTANCE_NAME`.h"
#include <device.h>
/******************************************************************************* 
* Function Name: `$INSTANCE_NAME`_Enable
********************************************************************************
*
* Summary: 
*  In Equation method, the Stainhart-Hart equation is used to obtain the temperature.
*  The digital values of the voltages across the reference resistor and the thermistor are passed to this function as parameters. 
*  These can be considered as the inputs to the component. The function returns (outputs) the temperature, based on the voltage values.
*  
*
* Parameters:  
*  Vreference is the voltage across the reference resistor. 
*  Vthermistor is the voltage across the thermistor.
*
* Return: 
*  The return value is the temperature. The return type is 32-bit integer as shown in the function prototype provided above. 
*  The value returned is the scaled version of temperature. The value is scaled up by 100 to avoid use of floating point math in the calculations. 
*  For example, the return value is 2345, when the actual temperature is 23.45 
*
* Reentrance: 
*  No
*
*******************************************************************************/
#if(`$INSTANCE_NAME`_IMPL ==1) 
	#include "math.h"
	int32 `$INSTANCE_NAME`_GetTemperature(int32 Vref, int32 VT)
	{
/* local variables */
		float LogrT;
		int32 iTemp_TR;
/* Calculate thermistor resistance from the voltages */		
		LogrT = log(`$INSTANCE_NAME`_Ref_Res *((float)(VT)/((float)(Vref))));
/* Calculate temperature from the resistance of thermistor using Steinhart-Hart Equation */
		iTemp_TR =(int32) (((1/(`$INSTANCE_NAME`_THA +(`$INSTANCE_NAME`_THB*LogrT)+(`$INSTANCE_NAME`_THC*pow(LogrT,3.0))))-273.15) * 100);
/* Return temperature */
		return(iTemp_TR);
	}
#endif

/******************************************************************************* 
* Function Name: `$INSTANCE_NAME`_Enable
********************************************************************************
*
* Summary: 
*  In LUT method, the look-up-table generated by the component customizer software is used to obtain the temperature.
*  The digital values of the voltages across the reference resistor and the thermistor are passed to this function as parameters. 
*  These can be considered as the inputs to the component. The function returns (outputs) the temperature, based on the voltage values.
*  
*
* Parameters:  
*  Vreference is the voltage across the reference resistor. 
*  Vthermistor is the voltage across the thermistor.
*
* Return: 
*  The return value is the temperature. The return type is 32-bit integer as shown in the function prototype provided above. 
*  The value returned is the scaled version of temperature. The value is scaled up by 100 to avoid use of floating point math in the calculations. 
*  For example, the return value is 2345, when the actual temperature is 23.45 
*
* Reentrance: 
*  No
*
*******************************************************************************/
#if (`$INSTANCE_NAME`_IMPL == 0)
	int32 `$INSTANCE_NAME`_GetTemperature(int32 Vref, int32 VT)
	{
/* local variables */
		CYCODE const uint32 `$INSTANCE_NAME`_LUTARR[`$INSTANCE_NAME`_LUTSIZE] = `$INSTANCE_NAME`_LUT;
		uint32 lRes_TR;
		int32 iTemp_TR;
		uint16 iLoop;
		uint8 iAccuracy;
/* Calculate thermistor resistance from the voltages */	
		lRes_TR= `$INSTANCE_NAME`_Ref_Res *(long)VT;
		lRes_TR = lRes_TR + (long)Vref/2;
		lRes_TR = lRes_TR / (long)Vref;
		iAccuracy = `$INSTANCE_NAME`_Accuracy * 100;
/* Calculate temperature from the resistance of thermistor by using the LUT */			
		for(iLoop =0; iLoop < `$INSTANCE_NAME`_LUTSIZE; iLoop++)
		{
			if(lRes_TR > `$INSTANCE_NAME`_LUTARR[iLoop])
			{
				break;
			}
		}
		iTemp_TR = `$INSTANCE_NAME`_MIN_TEMP * 100 + (iLoop * iAccuracy);
/* Return temperature */
		return(iTemp_TR);
	}
#endif

/* [] END OF FILE */
