using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;

namespace Thermistor_Calc_v1_0
{
    public partial class ThermistorControl : UserControl
    {
        private ThermistorParameters parameters;
        
#region CustomizerEvents
        public ThermistorControl(ThermistorParameters parameters)
        {
            InitializeComponent();
            this.parameters = parameters;
            UpdateForm();
        }
        private void m_text_RefRes_TextChanged(object sender, EventArgs e)
        {
            parameters.ReferenceResistor = Convert.ToUInt32(m_text_RefRes.Text);
        }

        private void m_Rbotton_LUT_CheckedChanged(object sender, EventArgs e)
        {
            parameters.Implementation = false;
            m_combo_accuracy.Enabled = true;
            m_text_LUTSize_Display.Enabled = true;
        }

        private void m_Rbutton_Equation_CheckedChanged(object sender, EventArgs e)
        {
            parameters.Implementation = true;
            m_combo_accuracy.Enabled = false;
            m_text_LUTSize_Display.Enabled = false;
        }
        private void m_combo_accuracy_SelectedIndexChanged(object sender, EventArgs e)
        {
            parameters.Accuracy = Convert.ToSingle(m_combo_accuracy.SelectedItem);
            m_text_LUTSize_Display.Text = Convert.ToString(Convert.ToSingle(parameters.MaxT - parameters.MinT) / parameters.Accuracy);
            ValidateRangeAccuracy();
        }
        private void m_numeric_MaxT_ValueChanged(object sender, EventArgs e)
        {
            parameters.MaxT = Convert.ToInt16(m_numeric_MaxT.Value);
            m_text_LUTSize_Display.Text = Convert.ToString(Convert.ToSingle(parameters.MaxT - parameters.MinT) / parameters.Accuracy);
            ValidateRangeAccuracy();
        }
        private void m_numeric_MidT_ValueChanged(object sender, EventArgs e)
        {
            parameters.MidT = Convert.ToInt16(m_numeric_MidT.Value);
        }
        private void m_numeric_MinT_ValueChanged(object sender, EventArgs e)
        {
            parameters.MinT = Convert.ToInt16(m_numeric_MinT.Value);
            m_text_LUTSize_Display.Text = Convert.ToString(Convert.ToSingle(parameters.MaxT - parameters.MinT) / parameters.Accuracy);
            ValidateRangeAccuracy();    
        }
        private void m_numeric_MaxR_ValueChanged(object sender, EventArgs e)
        {
            parameters.MaxR = Convert.ToUInt32(m_numeric_MaxR.Value);
        }
        private void m_numeric_MidR_ValueChanged(object sender, EventArgs e)
        {
            parameters.MidR = Convert.ToUInt32(m_numeric_MidR.Value);
        }
        private void m_numeric_MinR_ValueChanged(object sender, EventArgs e)
        {
            parameters.MinR = Convert.ToUInt32(m_numeric_MinR.Value);
        }
#endregion
        //Update Form Function
        private void ValidateRangeAccuracy()
        {
            if (Convert.ToUInt16(m_text_LUTSize_Display.Text) > 2000)
            {
                m_LUT_error.SetError(m_combo_accuracy, "LUT Cannot be greater than 2000. Lower the range or accuracy");
            }
            else
            {
                m_LUT_error.SetError(m_combo_accuracy, "");
            }
        }
        // Updates form with saved parameters when the GUI is opened.
        public void UpdateForm()
        {
            m_text_RefRes.Text = Convert.ToString(parameters.ReferenceResistor);
            m_combo_accuracy.SelectedItem = Convert.ToString(parameters.Accuracy);
            m_Rbotton_LUT.Checked = !(parameters.Implementation);
            m_Rbutton_Equation.Checked = parameters.Implementation;
            m_numeric_MaxT.Value = Convert.ToDecimal(parameters.MaxT);
            m_numeric_MidT.Value = Convert.ToDecimal(parameters.MidT);
            m_numeric_MinT.Value = Convert.ToDecimal(parameters.MinT);
            m_numeric_MaxR.Value = Convert.ToDecimal(parameters.MaxR);
            m_numeric_MidR.Value = Convert.ToDecimal(parameters.MidR);
            m_numeric_MinR.Value = Convert.ToDecimal(parameters.MinR);
            m_text_LUTSize_Display.Text = parameters.Lutsize.ToString();
        }

                                                             
    }
}
