using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Windows.Forms;
using CyDesigner.Extensions.Common;
using CyDesigner.Extensions.Gde;

namespace Thermistor_Calc_v1_0
{
    [CyCompDevCustomizer()]
    public partial class CyCustomizer : ICyParamEditHook_v1, ICyExprEval_v1
    {
        private const bool editParamsOnDrop = false;
        private const CyCompDevParamEditorMode mode = CyCompDevParamEditorMode.COMPLETE;
        private ThermistorParameters parameters;
        #region ICyExprEval_v1 Members
        public const string INSTANCE_NAME_PARAM = "INSTANCE_NAME";

        public CyExprEvalFunc GetFunction(string exprFuncName)
        {
            switch (exprFuncName)
            {
                // The name of this string constant is the same as what is used in Therm_v_0.cysym in the
                // NSF_RESULT parameter (I added this to your project). This is the name of the function
                // we want to add to our expressions.
                case "CalculateCoeffValue":

                    // The name of the argument to CyExprEvalFunc is name of the C# function
                    // that really implements the function. The whole point of this "GetFunction" method
                    // here is to tell PSoC Creator how to map the name it sees in the expression to 
                    // a real C# function that does the real work. Creator will call that other function
                    // as-needed.
                    return new CyExprEvalFunc(CalculateCoeffValue);

                default:
                    //Return null to indicate that the customizer didn't process the 
                    //function call so PSoC Creator should continue trying to process it.
                    return null;
            }
        }

        object CalculateCoeffValue(string exprFuncName, object[] args, ICyExprTypeConverter typeConverter)
        {
            string EqLUT;
            float MaxT, MidT, MinT, MaxR, MidR, MinR, Acc;
            float finvT1, finvT2, finvT3;
            double flnR1, flnR2, flnR3, flnR1P3, flnR2P3, flnR3P3;
            double fEq12a, fEq12b, fEq12c, fEq23a, fEq23b, fEq23c;
            float fTHA, fTHB, fTHC;
            int Impl;
            uint iLoop, iLutSize;
            float iTemp_Curr;
            float fRTHD, fRTHE;
            string InstanceName;
            UInt32 fRes;

            // Arguments are given in the "args" array. The "typeConverter" argument lets you get those 
            // values as normal C# types.
            if (args.Length != 9)
            {
                // We expect two arguments. If we see more or less we return an object that indicates there is an error.
                return new CyCustErr(string.Format(
                    "Incorrect number of arguements to call function '{0}' (nine arguements expected).",
                    exprFuncName));
            }
            else
            {
                // Everything is ok. Get our arguments as integers. For this demo, I return the sum. Put your
                // calculations here. The value is saved in NSF_RESULT -- look at Therm_v1_0.cysym at the local
                // parameters.
                MaxT = Convert.ToSingle(args[0]);
                MidT = Convert.ToSingle(args[1]);
                MinT = Convert.ToSingle(args[2]);
                MaxR = Convert.ToSingle(args[3]);
                MidR = Convert.ToSingle(args[4]);
                MinR = Convert.ToSingle(args[5]);
                Acc = Convert.ToSingle(args[6]);
                Impl = typeConverter.GetAsInt(args[7]);
                InstanceName = typeConverter.GetAsString(args[8]);
			
                finvT1 = 1 / (MaxT + 273);
                finvT2 = 1 / (MidT + 273);
                finvT3 = 1 / (MinT + 273);
                flnR1 = Math.Log(Convert.ToDouble(MaxR));
                flnR2 = Math.Log(Convert.ToDouble(MidR));
                flnR3 = Math.Log(Convert.ToDouble(MinR));
                flnR1P3 = Math.Pow(flnR1, 3);
                flnR2P3 = Math.Pow(flnR2, 3);
                flnR3P3 = Math.Pow(flnR3, 3);
                fEq12a = finvT1 - finvT2;
                fEq23a = finvT2 - finvT3;
                fEq12b = flnR1 - flnR2;
                fEq23b = flnR2 - flnR3;
                fEq12c = flnR1P3 - flnR2P3;
                fEq23c = flnR2P3 - flnR3P3;
                // Measuring the Coefficients from the parameters above
                fTHC = Convert.ToSingle((fEq12a * fEq23b - fEq23a * fEq12b) / (fEq12c * fEq23b - fEq23c * fEq12b));
                fTHB = Convert.ToSingle((fEq12a - (fEq12c * fTHC)) / fEq12b);
                fTHA = Convert.ToSingle(finvT1 - ((fTHB * flnR1) + (fTHC * flnR1P3)));

                if (Impl == 1)
                {
                    EqLUT = "#define" + '\t' + InstanceName + "_THA" + '\t' + Convert.ToString(fTHA) + '\n' + "#define" + '\t' + InstanceName + "_THB" + '\t' + Convert.ToString(fTHB) + '\n' + "#define" + '\t' + InstanceName + "_THC" + '\t' + Convert.ToString(fTHC);
                }
                else
                {
                    iLutSize = Convert.ToUInt16(Convert.ToSingle(MaxT - MinT) / Convert.ToSingle(Acc));
                    EqLUT = "#define" + '\t' + InstanceName + "_LUTSIZE" + '\t' + Convert.ToString(iLutSize) + '\n' + "#define" + '\t' + InstanceName + "_LUT" + '\t' + "{";
                    iTemp_Curr = MinT;
                    for (iLoop = 0; iLoop < iLutSize; iLoop++)
                    {
                        fRTHD = Convert.ToSingle((fTHA - (1 / (iTemp_Curr + 273))) / fTHC);
                        fRTHE = Convert.ToSingle(Math.Sqrt(Math.Pow(fTHB / (3 * fTHC), 3) + (Math.Pow(fRTHD, 2) / 4)));
						
						if(fRTHE > 0)
						{
                        fRes = Convert.ToUInt32(Math.Exp((Math.Pow((fRTHE - (fRTHD / 2)), 0.33333333) - Math.Pow((fRTHE + (fRTHD / 2)), 0.33333333))));
						}
						else
						{
						fRes =0;
						}
						if (iLoop < iLutSize - 1)
                            EqLUT = EqLUT + Convert.ToString(fRes) + ", ";
                        if (iLoop == iLutSize - 1)
                            EqLUT = EqLUT + Convert.ToString(fRes) + "} ";
                        iTemp_Curr = iTemp_Curr + Acc;
                    }
                }
                return (EqLUT);
            }
        }
        #endregion

        DialogResult ICyParamEditHook_v1.EditParams(ICyInstEdit_v1 edit, ICyTerminalQuery_v1 termQuery, ICyExpressMgr_v1 mgr)
        {
            parameters = new ThermistorParameters(edit);
            CyParamExprDelegate paramChange = delegate(ICyParamEditor custEditor, CyCompDevParam param)
            {
                parameters.GetParams();
            };

            ICyTabbedParamEditor editor = edit.CreateTabbedParamEditor();

            editor.AddCustomPage("Properties", new ThermistorEditingControl(parameters), paramChange, "Properties");

            editor.AddDefaultPage("Built-in", "Built-in");

            parameters.GetParams();

            return editor.ShowDialog();
        }

        bool ICyParamEditHook_v1.EditParamsOnDrop
        {
            get
            {
                return editParamsOnDrop;
            }
        }

        CyCompDevParamEditorMode ICyParamEditHook_v1.GetEditorMode()
        {
            return mode;
        }
    }

    public class ThermistorEditingControl : ICyParamEditingControl
    {
        private ThermistorControl control;

        public ThermistorEditingControl(ThermistorParameters parameters)
        {
            control = new ThermistorControl(parameters);
            parameters.control = control;
            control.Dock = DockStyle.Fill;
        }

        Control ICyParamEditingControl.DisplayControl
        {
            get { return control; }
        }

        IEnumerable<CyCustErr> ICyParamEditingControl.GetErrors()
        {
            return new CyCustErr[] { };
        }
    }
}