using System;
using System.Collections;
using System.Collections.Generic;
using System.Diagnostics;
using System.Drawing;
using System.IO;
using System.Windows.Forms;
using CyDesigner.Extensions.Gde;

namespace Thermistor_Calc_v1_0
{
    #region Component Parameters Names
    public class CyParamNames
    {
        public const string REFERENCE_RESISTOR = "ReferenceResistor";
        public const string IMPL = "Implementation_Equation";
        public const string ACCURACY = "Accuracy";
        public const string MAXT = "MAX_TEMP";
        public const string MIDT = "MID_TEMP";
        public const string MINT = "MIN_TEMP";
        public const string MAXR = "MAX_RES";
        public const string MIDR = "MID_RES";
        public const string MINR = "MIN_RES";
        public const string LUT = "LUT";
		public const string LUTSIZE = "LSIZE";
    }
    #endregion

    public class ThermistorParameters
    {
        private readonly ICyInstEdit_v1 m_edit;
        public ThermistorControl control;

        //Local Parameter Variables
        private UInt32 m_RefRes;
        private bool m_Impl;
        private float m_Acc;
        private Int16 m_MaxT;
        private Int16 m_MidT;
        private Int16 m_MinT;
        private UInt32 m_MaxR;
        private UInt32 m_MidR;
        private UInt32 m_MinR;
        private UInt16 m_LutSize;

        //Get Set Function for each parameter
        #region Class Properties

        public UInt32 ReferenceResistor
        {
            get { return m_RefRes; }
            set
            {
                m_RefRes = value;
                if (m_edit != null)
                {
                    m_edit.SetParamExpr(CyParamNames.REFERENCE_RESISTOR, m_RefRes.ToString());
                    m_edit.CommitParamExprs();
                }
            }
        }
        
        public bool Implementation
        {
            get { return m_Impl; }
            set
            {
                m_Impl = value;
                if (m_edit != null)
                {
                    m_edit.SetParamExpr(CyParamNames.IMPL, m_Impl.ToString());
                    m_edit.CommitParamExprs();
                }
            }
        }

        public float Accuracy
        {
            get { return m_Acc; }
            set
            {
                m_Acc = value;
                if (m_edit != null)
                {
                    m_edit.SetParamExpr(CyParamNames.ACCURACY, m_Acc.ToString());
                    m_edit.CommitParamExprs();
                }
            }
        }
        public Int16 MaxT
        {
            get { return m_MaxT; }
            set
            {
                m_MaxT = value;
                if (m_edit != null)
                {
                    m_edit.SetParamExpr(CyParamNames.MAXT, m_MaxT.ToString());
                    m_edit.CommitParamExprs();
                }
            }
        }
        public Int16 MidT
        {
            get { return m_MidT; }
            set
            {
                m_MidT = value;
                if (m_edit != null)
                {
                    m_edit.SetParamExpr(CyParamNames.MIDT, m_MidT.ToString());
                    m_edit.CommitParamExprs();
                }
            }
        }
        public Int16 MinT
        {
            get { return m_MinT; }
            set
            {
                m_MinT = value;
                if (m_edit != null)
                {
                    m_edit.SetParamExpr(CyParamNames.MINT, m_MinT.ToString());
                    m_edit.CommitParamExprs();
                }
            }
        }
        public UInt32 MaxR
        {
            get { return m_MaxR; }
            set
            {
                m_MaxR = value;
                if (m_edit != null)
                {
                    m_edit.SetParamExpr(CyParamNames.MAXR, m_MaxR.ToString());
                    m_edit.CommitParamExprs();
                }
            }
        }
        public UInt32 MidR
        {
            get { return m_MidR; }
            set
            {
                m_MidR = value;
                if (m_edit != null)
                {
                    m_edit.SetParamExpr(CyParamNames.MIDR, m_MidR.ToString());
                    m_edit.CommitParamExprs();
                }
            }
        }
        public UInt32 MinR
        {
            get { return m_MinR; }
            set
            {
                m_MinR = value;
                if (m_edit != null)
                {
                    m_edit.SetParamExpr(CyParamNames.MINR, m_MinR.ToString());
                    m_edit.CommitParamExprs();
                }
            }
        }
        public UInt16 Lutsize
        {
            get { return m_LutSize; }
            set
            {
                m_LutSize = value;
                if (m_edit != null)
                {
                    m_edit.SetParamExpr(CyParamNames.LUTSIZE, m_LutSize.ToString());
                    m_edit.CommitParamExprs();
                }
            }
        }
        #endregion


        public ThermistorParameters(ICyInstEdit_v1 m_edit)
        {
            this.m_edit = m_edit;
            GetParams();
        }

        //Get Commited Parameters from Customizer
        public void GetParams()
        {
            if (m_edit != null)
            {
                try
                {
                    m_RefRes = Convert.ToUInt32(m_edit.GetCommittedParam(CyParamNames.REFERENCE_RESISTOR).Value);//UInt32.Parse(m_edit.GetCommittedParam(CyParamNames.REFERENCE_RESISTOR).Value);
                }
                catch (Exception) { }

                try
                {
                    m_Impl = Convert.ToBoolean(m_edit.GetCommittedParam(CyParamNames.IMPL).Value);
                }
                catch (Exception) { }

                try
                {
                    m_Acc = Convert.ToSingle(m_edit.GetCommittedParam(CyParamNames.ACCURACY).Value);
                }
                catch (Exception) { }

                try
                {
                    m_MaxT = Convert.ToInt16(m_edit.GetCommittedParam(CyParamNames.MAXT).Value);
                }
                catch (Exception) { }

                try
                {
                    m_MidT = Convert.ToInt16(m_edit.GetCommittedParam(CyParamNames.MIDT).Value);
                }
                catch (Exception) { }
                
                try
                {
                    m_MinT = Convert.ToInt16(m_edit.GetCommittedParam(CyParamNames.MINT).Value);
                }
                catch (Exception) { }
                
                try
                {
                    m_MaxR = Convert.ToUInt32(m_edit.GetCommittedParam(CyParamNames.MAXR).Value);
                }
                catch (Exception) { }
                
                try
                {
                    m_MidR = Convert.ToUInt32(m_edit.GetCommittedParam(CyParamNames.MIDR).Value);
                }
                catch (Exception) { }
                
                try
                {
                    m_MinR = Convert.ToUInt32(m_edit.GetCommittedParam(CyParamNames.MINR).Value);
                }
                catch (Exception) { }
                try
                {
                     m_LutSize = Convert.ToUInt16(m_edit.GetCommittedParam(CyParamNames.LUTSIZE).Value);
                }
                catch (Exception) { }
            }
        }

        public void CommitParams()
        {
            if (m_edit != null)
            {
                if (!m_edit.CommitParamExprs())
                {
                    MessageBox.Show("Error in Commiting Parameters");
                }
            }
        }
    }
}